[X2Go-Commits] [python-x2go] 01/01: documentation: Correctly refrence X2GoClientPrinting and X2GoClientSettings. Also mention broker based X2GoSessionProfiles backends.

git-admin at x2go.org git-admin at x2go.org
Thu Sep 6 18:17:20 CEST 2018


This is an automated email from the git hooks/post-receive script.

x2go pushed a commit to branch master
in repository python-x2go.

commit eba55ce519aaa4f80441cd1d5162bd9ad58a1047
Author: Mike Gabriel <mike.gabriel at das-netzwerkteam.de>
Date:   Thu Sep 6 18:17:14 2018 +0200

    documentation: Correctly refrence X2GoClientPrinting and X2GoClientSettings. Also mention broker based X2GoSessionProfiles backends.
---
 x2go/__init__.py               | 22 +++++++++++++---------
 x2go/backends/settings/file.py |  6 +++---
 2 files changed, 16 insertions(+), 12 deletions(-)

diff --git a/x2go/__init__.py b/x2go/__init__.py
index 89d10f9..2ec7363 100644
--- a/x2go/__init__.py
+++ b/x2go/__init__.py
@@ -46,17 +46,21 @@ API Concept
     of future releases as compatible as possible with versions of Python X2Go
     greater/equal than v0.1.0.0.
 
-    The five public API classes are:
+    The seven public API classes are:
 
         - :class:`x2go.client.X2GoClient` --- a whole X2Go client API
         - :class:`x2go.session.X2GoSession` --- management of an individual X2Go
           session--either started standalone or from within an :class:`x2go.client.X2GoClient` instance
-        - :class:`x2go.backends.settings.base.X2GoClientSettings` --- provide access to X2Go (global and
+        - :class:`x2go.backends.settings.file.X2GoClientSettings` --- provide access to X2Go (global and
           user) configuration node »settings«
-        - :class:`x2go.backends.printing.base.X2GoClientPrinting` --- provide access to X2Go (global and
+        - :class:`x2go.backends.printing.file.X2GoClientPrinting` --- provide access to X2Go (global and
           user) configuration node »printing«
-        - :class:`x2go.backends.profiles.base.X2GoSessionProfiles` --- provide access to X2Go (global and
+        - :class:`x2go.backends.profiles.files.X2GoSessionProfiles` --- provide access to X2Go (global and
           user) configuration node »sessions«
+        - :class:`x2go.backends.profiles.httpbroker.X2GoSessionProfiles` --- provide API for obtaining
+          session profiles from a http(s) based X2Go Session Broker
+        - :class:`x2go.backends.profiles.sshbroker.X2GoSessionProfiles` --- provide API for obtaining
+          session profiles from an SSH based X2Go Session Broker
 
     Plus two extra classes on MS Windows platforms:
 
@@ -131,8 +135,8 @@ API Structure
     How to access---especially how to modify---the X2Go client configuration
     files »settings«, »printing«, »sessions« and »xconfig« (Windows only)
     is explained in detail with each class declaration in this API documentation.
-    Please refer to the class docs of :class:`x2go.backends.settings.base.X2GoClientSettings`, :class:`x2go.backends.printing.base.X2GoClientPrinting`,
-    :class:`x2go.backends.profiles.base.X2GoSessionProfiles` and :class:`x2go.xserver.X2GoXServer`.
+    Please refer to the class docs of :class:`x2go.backends.settings.file.X2GoClientSettings`, :class:`x2go.backends.printing.file.X2GoClientPrinting`,
+    :class:`x2go.backends.profiles.file.X2GoSessionProfiles` and :class:`x2go.xserver.X2GoXServer`.
 
 
 Configuration and Session Management
@@ -152,13 +156,13 @@ Configuration and Session Management
     Conclusively, any change to either of the configuration nodes
     will be reflected as a change in your X2Go client behaviour:
 
-      - :class:`x2go.backends.profiles.base.X2GoSessionProfiles`: changes to a session profile in
+      - :class:`x2go.backends.profiles.file.X2GoSessionProfiles`: changes to a session profile in
         the »sessions« node will be available for the next registered
         :class:`x2go.session.X2GoSession` instance
-      - :class:`x2go.backends.printing.base.X2GoClientPrinting`: on each incoming X2Go print job the
+      - :class:`x2go.backends.printing.file.X2GoClientPrinting`: on each incoming X2Go print job the
         »printing« configuration node will be re-read, thus you can
         change your X2Go client's print setup during a running session
-      - :class:`x2go.backends.settings.base.X2GoClientSettings`: also the configuration node »settings«
+      - :class:`x2go.backends.settings.file.X2GoClientSettings`: also the configuration node »settings«
         is re-read whenever needed in the course of X2Go session management
       - :class:`x2go.xserver.X2GoClientXConfig` and :class:`x2go.xserver.X2GoXServer` (Windows only): these classes will only be initialized
         once (starting the XServer on Windows platforms) on construction
diff --git a/x2go/backends/settings/file.py b/x2go/backends/settings/file.py
index c0d9a1a..20391bc 100644
--- a/x2go/backends/settings/file.py
+++ b/x2go/backends/settings/file.py
@@ -48,11 +48,11 @@ class X2GoClientSettings(inifiles.X2GoIniFile):
     """
     def __init__(self, config_files=_X2GO_SETTINGS_CONFIGFILES, defaults=_X2GO_CLIENTSETTINGS_DEFAULTS, logger=None, loglevel=log.loglevel_DEFAULT):
         """\
-        Constructs an :class:`x2go.backends.settings.base.X2GoClientSettings` instance. This is normally done from within an :class:`x2go.client.X2GoClient` instance.
-        You can retrieve this :class:`x2go.backends.settings.base.X2GoClientSettings` instance with the :func:`X2GoClient.get_client_settings() <x2go.client.X2GoClient.get_client_settings()>`
+        Constructs an :class:`x2go.backends.settings.file.X2GoClientSettings` instance. This is normally done from within an :class:`x2go.client.X2GoClient` instance.
+        You can retrieve this :class:`x2go.backends.settings.file.X2GoClientSettings` instance with the :func:`X2GoClient.get_client_settings() <x2go.client.X2GoClient.get_client_settings()>`
         method.
 
         On construction the :class:`x2go.backends.settings.base.X2GoClientSettings` object is filled with values from the configuration files::
 
             /etc/x2goclient/settings
             ~/.x2goclient/settings
@@ -48,11 +48,11 @@ class X2GoClientSettings(inifiles.X2GoIniFile):
         method.
 
-        On construction the :class:`x2go.backends.settings.base.X2GoClientSettings` object is filled with values from the configuration files::
+        On construction the :class:`x2go.backends.settings.file.X2GoClientSettings` object is filled with values from the configuration files::
 
             /etc/x2goclient/settings

--
Alioth's /home/x2go-admin/maintenancescripts/git/hooks/post-receive-email on /srv/git/code.x2go.org/python-x2go.git


More information about the x2go-commits mailing list